@@ -6,9 +6,9 @@
 #define OPENCV_DNN_VERSION_HPP
 
 /// Use with major OpenCV version only.
-#define OPENCV_DNN_API_VERSION 20181221
+#define OPENCV_DNN_API_VERSION 20200310
 
-#if !defined CV_DOXYGEN && !defined CV_DNN_DONT_ADD_INLINE_NS
+#if !defined CV_DOXYGEN && !defined CV_STATIC_ANALYSIS && !defined CV_DNN_DONT_ADD_INLINE_NS
 #define CV__DNN_INLINE_NS __CV_CAT(dnn4_v, OPENCV_DNN_API_VERSION)
 #define CV__DNN_INLINE_NS_BEGIN namespace CV__DNN_INLINE_NS {
 #define CV__DNN_INLINE_NS_END }
